class puppet_enterprise::profile::console::apache_proxy (
  $certname = $::clientcert,
  $trapperkeeper_proxy_listen_address = $puppet_enterprise::params::plaintext_address,
  $trapperkeeper_proxy_listen_port    = $puppet_enterprise::params::console_services_listen_port,
  $ssl_listen_address      = $puppet_enterprise::params::ssl_address,
  $ssl_listen_port         = $puppet_enterprise::console_port,
  $browser_ssl_cert        = undef,
  $browser_ssl_private_key = undef,
  $browser_ssl_cert_chain  = undef,
  $browser_ssl_ca_cert     = undef,
) inherits puppet_enterprise {
  $cert_dir = '/opt/puppet/share/console-services/certs'
  # puppet_enterprise::certs { 'pe-console-services' : ... } -> creates these files
  if $browser_ssl_cert != undef and $browser_ssl_private_key != undef {
    $ssl_key = $browser_ssl_private_key
    $ssl_cert = $browser_ssl_cert
  } else {
    $ssl_key = "${cert_dir}/${certname}.private_key.pem"
    $ssl_cert =  "${cert_dir}/${certname}.cert.pem"
  }

  if $browser_ssl_cert_chain != undef {
    $ssl_cert_chain = $browser_ssl_cert_chain
  } else {
    $ssl_cert_chain = $puppet_enterprise::params::localcacert
  }

  if $browser_ssl_ca_cert != undef {
    $ssl_ca_cert = $browser_ssl_ca_cert
  } else {
    $ssl_ca_cert = $puppet_enterprise::params::localcacert
  }

  # Uses
  # $trapperkeeper_proxy_listen_address
  # $trapperkeeper_proxy_listen_port
  # $ssl_key
  # $ssl_cert
  # $ssl_cert_chain
  # $ssl_ca_cert
  # $ssl_listen_address
  # $ssl_listen_port
  file { '/etc/puppetlabs/httpd/conf.d/puppetproxy.conf':
    owner   => $puppet_enterprise::params::root_user,
    group   => $puppet_enterprise::params::root_group,
    mode    => '0644',
    content => template('puppet_enterprise/profile/console-services/puppetproxy.conf.erb'),
    notify  => Service['pe-httpd'],
    require => Puppet_enterprise::Certs['pe-console-services::server_cert'],
  }
}
