define puppet_enterprise::trapperkeeper::console_services(
  $rbac_host,
  $classifier_host,
  $activity_host,
  $puppetdb_host,
  $proxy_idle_timeout    = undef,
  $client_certname       = $puppet_enterprise::params::console_client_certname,
  $container             = $title,
  $user                  = "pe-${title}",
  $group                 = "pe-${title}",
  $classifier_port       = $puppet_enterprise::params::console_services_api_listen_port,
  $dashboard_port        = $puppet_enterprise::params::dashboard_listen_port,
  $classifier_url_prefix = $puppet_enterprise::params::classifier_url_prefix,
  $rbac_port             = $puppet_enterprise::params::console_services_api_listen_port,
  $rbac_url_prefix       = $puppet_enterprise::params::rbac_url_prefix,
  $activity_port         = $puppet_enterprise::params::console_services_api_listen_port,
  $activity_url_prefix   = $puppet_enterprise::params::activity_url_prefix,
  $puppetdb_port         = $puppet_enterprise::params::puppetdb_ssl_listen_port,
  $localcacert           = $puppet_enterprise::params::localcacert,
) {

  $cert_dir = "/opt/puppet/share/${container}/certs"
  $ssl_key = "${cert_dir}/${client_certname}.private_key.pem"
  $ssl_cert =  "${cert_dir}/${client_certname}.cert.pem"

  $cookie_secret_key = cookie_secret_key()

  # Uses
  #   $ssl_key
  #   $ssl_cert
  #   $localcacert
  #   $puppetdb
  #   $puppetdb_port
  #   $rbac
  #   $rbac_port
  #   $rbac_url_prefix
  #   $classifier
  #   $classifier_port
  #   $dashboard_port
  #   $classifier_url_prefix
  #   $activity
  #   $activity_port
  #   $activity_url_prefix
  #   $proxy_idle_timeout
  file { "/etc/puppetlabs/${container}/conf.d/console.conf":
    content => template('puppet_enterprise/trapperkeeper/console-services/console.conf.erb'),
    owner   => $user,
    group   => $group,
    mode    => '0640',
  }

  # Uses
  #   $cookie_secret_key
  file { "/etc/puppetlabs/${container}/conf.d/console_secret_key.conf":
    content => template('puppet_enterprise/trapperkeeper/console-services/console_secret_key.conf.erb'),
    replace => false,
    owner   => $user,
    group   => $group,
    mode    => '0640',
  }

  puppet_enterprise::trapperkeeper::bootstrap_cfg { "${container}:console webrouting-service" :
    container => $container,
    namespace => 'puppetlabs.trapperkeeper.services.webrouting.webrouting-service',
    service   => 'webrouting-service',
  }

  puppet_enterprise::trapperkeeper::bootstrap_cfg { "${container}:console rbac-ui-service" :
    container => $container,
    namespace => 'puppetlabs.rbac-ui.service',
    service   => 'rbac-ui-service',
  }

  puppet_enterprise::trapperkeeper::bootstrap_cfg { "${container}:console rbac-service" :
    container => $container,
    namespace => 'puppetlabs.rbac.services.rbac',
    service   => 'rbac-service',
  }
  puppet_enterprise::trapperkeeper::bootstrap_cfg { "${container}:console rbac-authn-middleware" :
    container => $container,
    namespace => 'puppetlabs.rbac.services.http.middleware',
    service   => 'rbac-authn-middleware',
  }

  puppet_enterprise::trapperkeeper::bootstrap_cfg { "${container}:console rbac-storage-service" :
    container => $container,
    namespace => 'puppetlabs.rbac.services.storage.permissioned',
    service   => 'rbac-storage-service',
  }

  puppet_enterprise::trapperkeeper::bootstrap_cfg { "${container}:console proxy-service" :
    container => $container,
    namespace => 'puppetlabs.proxy.services.proxy',
    service   => 'proxy-service',
  }
  puppet_enterprise::trapperkeeper::bootstrap_cfg { "${container}:console helpers-service" :
    container => $container,
    namespace => 'puppetlabs.proxy.services.proxy',
    service   => 'helpers-service',
  }

  puppet_enterprise::trapperkeeper::bootstrap_cfg { "${container}:console rbac-authn-service" :
    container => $container,
    namespace => 'puppetlabs.rbac.services.authn',
    service   => 'rbac-authn-service',
  }

  puppet_enterprise::trapperkeeper::bootstrap_cfg { "${container}:console rbac-authz-service" :
    container => $container,
    namespace => 'puppetlabs.rbac.services.authz',
    service   => 'rbac-authz-service',
  }

  puppet_enterprise::trapperkeeper::bootstrap_cfg { "${container}:console classifier-ui-service" :
    container => $container,
    namespace => 'puppetlabs.classifier-ui.service',
    service   => 'classifier-ui-service',
  }

  puppet_enterprise::trapperkeeper::bootstrap_cfg { "${container}:console jetty9-service" :
    container => $container,
    namespace => 'puppetlabs.trapperkeeper.services.webserver.jetty9-service',
    service   => 'jetty9-service',
  }

}

