require 'spec_helper'

describe 'puppet_enterprise::mcollective::server::facter' do
  before :each do
    @facter_facts = {
      'osfamily'          => 'RedHat',
      'lsbmajdistrelease' => '6',
      'puppetversion'     => '3.6.2 (Puppet Enterprise 3.3.0)',
      'is_pe'             => 'true',
      'fqdn'              => 'somenode.rspec',
      'clientcert'        => 'awesomecert',
    }
  end

  let(:facts) { @facter_facts }
  let(:winfile) { 'refresh-mcollective-metadata.bat' }
  let(:unixfile) { '/opt/puppet/sbin/refresh-mcollective-metadata' }
  let(:cronname) { 'pe-mcollective-metadata' }

  context "on a windows machine" do
    before :each do
      @facter_facts['osfamily'] = 'windows'
      @facter_facts['operatingsystem'] = 'windows'
    end

    it "the catalog compiles" do
      subject
    end

    it { should contain_scheduled_task('pe-mcollective-metadata') }
  end

  context "on a AIX machine" do
    before :each do
      @facter_facts['operatingsystem'] = 'AIX'
    end

    it "the catalog compiles" do
      subject
    end

    it { should contain_file(unixfile).with(
      'owner' => 'root',
      'group' => 'system',
      'mode'  => '0775',
    )}

    it { should contain_cron(cronname).with(
      'user' => 'root',
    )}
  end

  context "on a RedHat machine" do
    it "the catalog compiles" do
      subject
    end

    it { should contain_file(unixfile).with(
      'owner' => 'root',
      'group' => 'root',
      'mode'  => '0775',
    )}

    it { should contain_cron(cronname).with(
      'user' => 'root',
    )}
  end


  it { should satisfy_all_relationships }
end
